@@ -256,6 +256,10 @@ ario_filesystem_init (ArioFilesystem *filesystem)
         gtk_tree_view_set_model (GTK_TREE_VIEW (filesystem->priv->tree),
                                  GTK_TREE_MODEL (filesystem->priv->model));
 
+        /* Enable search */
+        gtk_tree_view_set_enable_search (GTK_TREE_VIEW (filesystem->priv->tree), TRUE);
+        gtk_tree_view_set_search_column (GTK_TREE_VIEW (filesystem->priv->tree), FILETREE_NAME_COLUMN);
+
         /* Get tree selection */
         filesystem->priv->selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (filesystem->priv->tree));
         gtk_tree_selection_set_mode (filesystem->priv->selection,
@@ -583,7 +587,7 @@ ario_filesystem_cursor_moved_cb (GtkTreeView *tree_view,
 
 static void
 ario_filesystem_add_filetree (ArioFilesystem *filesystem,
-                              gboolean play)
+                              PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         gchar *dir;
@@ -603,7 +607,7 @@ ario_filesystem_add_filetree (ArioFilesystem *filesystem,
         g_return_if_fail (dir);
 
         /* Append songs in folder to playlist */
-        ario_server_playlist_append_dir (dir, play);
+        ario_server_playlist_append_dir (dir, action);
         g_free (dir);
 }
 
@@ -613,7 +617,7 @@ ario_filesystem_cmd_add_filesystem (GtkAction *action,
 {
         ARIO_LOG_FUNCTION_START;
         /* Append songs in selected folder to playlist */
-        ario_filesystem_add_filetree (filesystem, FALSE);
+        ario_filesystem_add_filetree (filesystem, PLAYLIST_ADD);
 }
 
 static void
@@ -622,7 +626,7 @@ ario_filesystem_cmd_add_play_filesystem (GtkAction *action,
 {
         ARIO_LOG_FUNCTION_START;
         /* Append songs in selected folder to playlist */
-        ario_filesystem_add_filetree (filesystem, TRUE);
+        ario_filesystem_add_filetree (filesystem, PLAYLIST_ADD_PLAY);
 }
 
 static void
@@ -630,11 +634,8 @@ ario_filesystem_cmd_clear_add_play_filesystem (GtkAction *action,
                                                ArioFilesystem *filesystem)
 {
         ARIO_LOG_FUNCTION_START;
-        /* Empty playlist */
-        ario_server_clear ();
-
-        /* Append songs in selected folder to playlist */
-        ario_filesystem_add_filetree (filesystem, TRUE);
+        /* Clear playlist, append songs in selected folder to playlist */
+        ario_filesystem_add_filetree (filesystem, PLAYLIST_REPLACE);
 }
 
 static void
@@ -681,7 +682,7 @@ ario_filesystem_filetree_drag_data_get_cb (GtkWidget * widget,
                             FILETREE_DIR_COLUMN, &dir, -1);
 
         /* Set drag data */
-        gtk_selection_data_set (selection_data, selection_data->target, 8, dir,
+        gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data), 8, dir,
                                 strlen ((const gchar*) dir) * sizeof(guchar));
         g_free (dir);
 }
