@@ -36,6 +36,7 @@ typedef struct
         gchar *name;
         gchar *host;
         int port;
+        int timeout;
         gchar *password;
         gchar *musicdir;
         gboolean local;
@@ -54,6 +55,8 @@ ArioProfile*            ario_profiles_get_current       (GSList* profiles);
 void                    ario_profiles_set_current       (GSList* profiles,
                                                          ArioProfile* profile);
 
+void                    ario_profiles_set_current_by_name (const gchar * profile);
+
 G_END_DECLS
 
 #endif /* __ARIO_PROFILES_H */
