@@ -47,19 +47,19 @@
 #define MPD_ERRORSTR_MAX_LENGTH	1000
 #define MPD_WELCOME_MESSAGE	"OK MPD "
 
-#define MPD_ERROR_TIMEOUT	10 /* timeout trying to talk to mpd */
-#define MPD_ERROR_SYSTEM	11 /* system error */
-#define MPD_ERROR_UNKHOST	12 /* unknown host */
-#define MPD_ERROR_CONNPORT	13 /* problems connecting to port on host */
-#define MPD_ERROR_NOTMPD	14 /* mpd not running on port at host */
-#define MPD_ERROR_NORESPONSE	15 /* no response on attempting to connect */
-#define MPD_ERROR_SENDING	16 /* error sending command */
-#define MPD_ERROR_CONNCLOSED	17 /* connection closed by mpd */
-#define MPD_ERROR_ACK		18 /* ACK returned! */
-#define MPD_ERROR_BUFFEROVERRUN	19 /* Buffer was overrun! */
+#define MPD_ERROR_1_TIMEOUT	10 /* timeout trying to talk to mpd */
+#define MPD_ERROR_1_SYSTEM	11 /* system error */
+#define MPD_ERROR_1_UNKHOST	12 /* unknown host */
+#define MPD_ERROR_1_CONNPORT	13 /* problems connecting to port on host */
+#define MPD_ERROR_1_NOTMPD	14 /* mpd not running on port at host */
+#define MPD_ERROR_1_NORESPONSE	15 /* no response on attempting to connect */
+#define MPD_ERROR_1_SENDING	16 /* error sending command */
+#define MPD_ERROR_1_CONNCLOSED	17 /* connection closed by mpd */
+#define MPD_ERROR_1_ACK		18 /* ACK returned! */
+#define MPD_ERROR_1_BUFFEROVERRUN	19 /* Buffer was overrun! */
 
 #define MPD_ACK_ERROR_UNK	-1
-#define MPD_ERROR_AT_UNK	-1
+#define MPD_ERROR_1_AT_UNK	-1
 
 #define MPD_ACK_ERROR_NOT_LIST			1
 #define MPD_ACK_ERROR_ARG			2
@@ -83,6 +83,7 @@ typedef enum mpd_TagItems
 {
 	MPD_TAG_ITEM_ARTIST,
 	MPD_TAG_ITEM_ALBUM,
+	MPD_TAG_ITEM_ALBUM_ARTIST,
 	MPD_TAG_ITEM_TITLE,
 	MPD_TAG_ITEM_TRACK,
 	MPD_TAG_ITEM_NAME,
@@ -93,7 +94,6 @@ typedef enum mpd_TagItems
 	MPD_TAG_ITEM_COMMENT,
 	MPD_TAG_ITEM_DISC,
 	MPD_TAG_ITEM_FILENAME,
-	MPD_TAG_ITEM_ALBUMARTIST,
 	MPD_TAG_ITEM_ANY,
 	MPD_TAG_NUM_OF_ITEM_TYPES
 } mpd_TagItems;
@@ -144,7 +144,7 @@ typedef struct _mpd_Connection {
 	char errorStr[MPD_ERRORSTR_MAX_LENGTH+1];
 	int errorCode;
 	int errorAt;
-	/* this will be set to MPD_ERROR_* if there is an error, 0 if not */
+	/* this will be set to MPD_ERROR_1_* if there is an error, 0 if not */
 	int error;
 	/* DON'T TOUCH any of the rest of this stuff */
 	int sock;
