@@ -349,6 +349,7 @@ ario_plugins_engine_shutdown (void)
          * finalization (typically they need to free the WindowData)
          * it must run before we get rid of the plugins.
          */
+        ario_python_garbage_collect ();
         ario_python_shutdown ();
 #endif
 
@@ -461,7 +462,7 @@ ario_plugins_engine_configure_plugin (ArioPluginInfo    *info,
         gtk_window_set_transient_for (GTK_WINDOW (conf_dlg),
                                       parent);
 
-        wg = parent->group;
+        wg = gtk_window_get_group (parent);
         if (wg == NULL) {
                 wg = gtk_window_group_new ();
                 gtk_window_group_add_window (wg, parent);
@@ -503,12 +504,3 @@ ario_plugins_engine_active_plugins_changed (void)
         g_slist_free (active_plugins);
 }
 
-#ifdef ENABLE_PYTHON
-void
-ario_plugins_engine_garbage_collect (void)
-{
-        ario_python_garbage_collect ();
-}
-#endif
-
-
