@@ -20,24 +20,20 @@
 #include "preferences/ario-cover-preferences.h"
 #include <config.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
-#include <stdlib.h>
 #include <string.h>
-#include <time.h>
-#include <glib/gi18n.h>
-#include "preferences/ario-preferences.h"
-#include "covers/ario-cover-manager.h"
-#include "lib/rb-glade-helpers.h"
-#include "lib/ario-conf.h"
-#include "ario-avahi.h"
+
 #include "ario-debug.h"
+#include "covers/ario-cover-manager.h"
+#include "lib/ario-conf.h"
+#include "lib/gtk-builder-helpers.h"
+#include "preferences/ario-preferences.h"
 
 static void ario_cover_preferences_sync_cover (ArioCoverPreferences *cover_preferences);
 G_MODULE_EXPORT void ario_cover_preferences_covertree_check_changed_cb (GtkCheckButton *butt,
                                                                         ArioCoverPreferences *cover_preferences);
 G_MODULE_EXPORT void ario_cover_preferences_automatic_check_changed_cb (GtkCheckButton *butt,
                                                                         ArioCoverPreferences *cover_preferences);
-G_MODULE_EXPORT void ario_cover_preferences_amazon_country_changed_cb (GtkComboBoxEntry *combobox,
+G_MODULE_EXPORT void ario_cover_preferences_amazon_country_changed_cb (GtkComboBox *combobox,
                                                                        ArioCoverPreferences *cover_preferences);
 G_MODULE_EXPORT void ario_cover_preferences_top_button_cb (GtkWidget *widget,
                                                            ArioCoverPreferences *cover_preferences);
@@ -47,22 +43,22 @@ G_MODULE_EXPORT void ario_cover_preferences_down_button_cb (GtkWidget *widget,
                                                             ArioCoverPreferences *cover_preferences);
 G_MODULE_EXPORT void ario_cover_preferences_bottom_button_cb (GtkWidget *widget,
                                                               ArioCoverPreferences *cover_preferences);
-static void ario_cover_preferences_cover_toggled_cb (GtkCellRendererToggle *cell,
-                                                     gchar *path_str,
-                                                     ArioCoverPreferences *cover_preferences);
-
+G_MODULE_EXPORT void ario_cover_preferences_cover_toggled_cb (GtkCellRendererToggle *cell,
+                                                              gchar *path_str,
+                                                              ArioCoverPreferences *cover_preferences);
 
+/* Private attributes */
 struct ArioCoverPreferencesPrivate
 {
         GtkWidget *covertree_check;
         GtkWidget *automatic_check;
         GtkWidget *amazon_country;
 
-        GtkWidget *covers_treeview;
         GtkListStore *covers_model;
         GtkTreeSelection *covers_selection;
 };
 
+/* Tree model columns */
 enum
 {
         ENABLED_COLUMN,
@@ -71,125 +67,74 @@ enum
         N_COLUMN
 };
 
-static const char *amazon_countries[] = {
-        "com",
-        "fr",
-        "de",
-        "uk",
-        "ca",
-        "jp",
-        NULL
-};
-
 #define ARIO_COVER_PREFERENCES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ARIO_COVER_PREFERENCES, ArioCoverPreferencesPrivate))
 G_DEFINE_TYPE (ArioCoverPreferences, ario_cover_preferences, GTK_TYPE_VBOX)
 
 static void
 ario_cover_preferences_class_init (ArioCoverPreferencesClass *klass)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
+        /* Private attributes */
         g_type_class_add_private (klass, sizeof (ArioCoverPreferencesPrivate));
 }
 
 static void
 ario_cover_preferences_init (ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         cover_preferences->priv = ARIO_COVER_PREFERENCES_GET_PRIVATE (cover_preferences);
 }
 
 GtkWidget *
 ario_cover_preferences_new (void)
 {
-        ARIO_LOG_FUNCTION_START
-        GladeXML *xml;
+        ARIO_LOG_FUNCTION_START;
+        GtkBuilder *builder;
         ArioCoverPreferences *cover_preferences;
-        GtkListStore *list_store;
-        GtkCellRenderer *renderer;
-        GtkTreeIter iter;
-        int i;
-        GtkTreeViewColumn *column;
+        GtkWidget *covers_treeview;
 
         cover_preferences = g_object_new (TYPE_ARIO_COVER_PREFERENCES, NULL);
 
         g_return_val_if_fail (cover_preferences->priv != NULL, NULL);
 
-        xml = rb_glade_xml_new (GLADE_PATH "cover-prefs.glade",
-                                "covers_vbox",
-                                cover_preferences);
+        /* Generate UI using GtkBuilder */
+        builder = gtk_builder_helpers_new (UI_PATH "cover-prefs.ui",
+                                           cover_preferences);
 
+        /* Get pointers to various widgets */
         cover_preferences->priv->covertree_check =
-                glade_xml_get_widget (xml, "covertree_checkbutton");
+                GTK_WIDGET (gtk_builder_get_object (builder, "covertree_checkbutton"));
         cover_preferences->priv->automatic_check =
-                glade_xml_get_widget (xml, "automatic_checkbutton");
+                GTK_WIDGET (gtk_builder_get_object (builder, "automatic_checkbutton"));
         cover_preferences->priv->amazon_country =
-                glade_xml_get_widget (xml, "amazon_country_combobox");
-        cover_preferences->priv->covers_treeview = 
-                glade_xml_get_widget (xml, "covers_treeview");
+                GTK_WIDGET (gtk_builder_get_object (builder, "amazon_country_combobox"));
+        cover_preferences->priv->covers_model =
+                GTK_LIST_STORE (gtk_builder_get_object (builder, "covers_model"));
+        covers_treeview =
+                GTK_WIDGET (gtk_builder_get_object (builder, "covers_treeview"));
 
-        rb_glade_boldify_label (xml, "cover_frame_label");
-        rb_glade_boldify_label (xml, "cover_sources_frame_label");
+        /* Set style for labels */
+        gtk_builder_helpers_boldify_label (builder, "cover_frame_label");
+        gtk_builder_helpers_boldify_label (builder, "cover_sources_frame_label");
 
-        list_store = gtk_list_store_new (1, G_TYPE_STRING);
-
-        for (i = 0; amazon_countries[i]; ++i) {
-                gtk_list_store_append (list_store, &iter);
-                gtk_list_store_set (list_store, &iter,
-                                    0, amazon_countries[i],
-                                    -1);
-        }
-
-        gtk_combo_box_set_model (GTK_COMBO_BOX (cover_preferences->priv->amazon_country),
-                                 GTK_TREE_MODEL (list_store));
-        g_object_unref (list_store);
-
-        renderer = gtk_cell_renderer_text_new ();
-        gtk_cell_layout_clear (GTK_CELL_LAYOUT (cover_preferences->priv->amazon_country));
-        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (cover_preferences->priv->amazon_country), renderer, TRUE);
-        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (cover_preferences->priv->amazon_country), renderer,
-                                        "text", 0, NULL);
-
-        cover_preferences->priv->covers_model = gtk_list_store_new (N_COLUMN,
-                                                                    G_TYPE_BOOLEAN,
-                                                                    G_TYPE_STRING,
-                                                                    G_TYPE_STRING);
-        gtk_tree_view_set_model (GTK_TREE_VIEW (cover_preferences->priv->covers_treeview),
-                                 GTK_TREE_MODEL (cover_preferences->priv->covers_model));
-        renderer = gtk_cell_renderer_toggle_new ();
-        column = gtk_tree_view_column_new_with_attributes (_("Enabled"),
-                                                           renderer,
-                                                           "active", ENABLED_COLUMN,
-                                                           NULL);
-        gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
-        gtk_tree_view_column_set_fixed_width (column, 80);
-        gtk_tree_view_append_column (GTK_TREE_VIEW (cover_preferences->priv->covers_treeview), column);
-        g_signal_connect (GTK_OBJECT (renderer),
-                          "toggled",
-                          G_CALLBACK (ario_cover_preferences_cover_toggled_cb), cover_preferences);
-        renderer = gtk_cell_renderer_text_new ();
-        column = gtk_tree_view_column_new_with_attributes (_("Name"),
-                                                           renderer,
-                                                           "text", NAME_COLUMN,
-                                                           NULL);
-        gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
-        gtk_tree_view_append_column (GTK_TREE_VIEW (cover_preferences->priv->covers_treeview), column);
-
-        cover_preferences->priv->covers_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (cover_preferences->priv->covers_treeview));
+        /* Get model selection */
+        cover_preferences->priv->covers_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (covers_treeview));
         gtk_tree_selection_set_mode (cover_preferences->priv->covers_selection,
                                      GTK_SELECTION_BROWSE);
 
+        /* Synchronize widgets with configuration */
         ario_cover_preferences_sync_cover (cover_preferences);
 
-        gtk_box_pack_start (GTK_BOX (cover_preferences), glade_xml_get_widget (xml, "covers_vbox"), TRUE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (cover_preferences), GTK_WIDGET (gtk_builder_get_object (builder, "covers_vbox")), TRUE, TRUE, 0);
 
-        g_object_unref (G_OBJECT (xml));
+        g_object_unref (builder);
         return GTK_WIDGET (cover_preferences);
 }
 
 static void
 ario_cover_preferences_sync_cover_providers (ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         ArioCoverProvider *cover_provider;
         GSList *providers;
         GSList *tmp;
@@ -198,16 +143,24 @@ ario_cover_preferences_sync_cover_providers (ArioCoverPreferences *cover_prefere
         gchar *tmp_id;
         GtkTreeModel *model = GTK_TREE_MODEL (cover_preferences->priv->covers_model);
 
+        /* Remember id of currently selected row */
         if (gtk_tree_selection_get_selected (cover_preferences->priv->covers_selection,
                                              &model,
                                              &iter)) {
                 gtk_tree_model_get (model, &iter, ID_COLUMN, &id, -1);
         }
 
+        /* Empty list */
         gtk_list_store_clear (cover_preferences->priv->covers_model);
+
+        /* Get all covers providers */
         providers = ario_cover_manager_get_providers (ario_cover_manager_get_instance ());
+
+        /* For each covers provider */
         for (tmp = providers; tmp; tmp = g_slist_next (tmp)) {
                 cover_provider = (ArioCoverProvider *) tmp->data;
+
+                /* Append cover provider to tree */
                 gtk_list_store_append (cover_preferences->priv->covers_model, &iter);
                 gtk_list_store_set (cover_preferences->priv->covers_model, &iter,
                                     ENABLED_COLUMN, ario_cover_provider_is_active (cover_provider),
@@ -216,6 +169,7 @@ ario_cover_preferences_sync_cover_providers (ArioCoverPreferences *cover_prefere
                                     -1);
         }
 
+        /* Select again previously selected row */
         if (id) {
                 if (gtk_tree_model_get_iter_first (model, &iter)) {
                         do {
@@ -230,29 +184,52 @@ ario_cover_preferences_sync_cover_providers (ArioCoverPreferences *cover_prefere
         }
 }
 
+static gboolean
+ario_cover_preferences_sync_cover_foreach (GtkTreeModel *model,
+                                           GtkTreePath *path,
+                                           GtkTreeIter *iter,
+                                           ArioCoverPreferences *cover_preferences)
+{
+        ARIO_LOG_FUNCTION_START;
+        gchar *country;
+
+        /* Get country of current row */
+        gtk_tree_model_get (model, iter,
+                            0, &country,
+                            -1);
+
+        if (!strcmp (country, ario_conf_get_string (PREF_COVER_AMAZON_COUNTRY, PREF_COVER_AMAZON_COUNTRY_DEFAULT))) {
+                /* Row of current country foud: activate this row */
+                gtk_combo_box_set_active_iter (GTK_COMBO_BOX (cover_preferences->priv->amazon_country), iter);
+                g_free (country);
+                /* Stop iterations */
+                return TRUE;
+        }
+        g_free (country);
+
+        /* Continue iterations */
+        return FALSE;
+}
+
 static void
 ario_cover_preferences_sync_cover (ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
-        int i;
-        char *current_country;
+        ARIO_LOG_FUNCTION_START;
 
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cover_preferences->priv->covertree_check), 
+        /* Activate covertre_check */
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cover_preferences->priv->covertree_check),
                                       !ario_conf_get_boolean (PREF_COVER_TREE_HIDDEN, PREF_COVER_TREE_HIDDEN_DEFAULT));
 
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cover_preferences->priv->automatic_check), 
+        /* Activate automatic_check */
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cover_preferences->priv->automatic_check),
                                       ario_conf_get_boolean (PREF_AUTOMATIC_GET_COVER, PREF_AUTOMATIC_GET_COVER_DEFAULT));
 
-        current_country = ario_conf_get_string (PREF_COVER_AMAZON_COUNTRY, PREF_COVER_AMAZON_COUNTRY_DEFAULT);
-        for (i = 0; amazon_countries[i]; ++i) {
-                if (!strcmp (amazon_countries[i], current_country)) {
-                        gtk_combo_box_set_active (GTK_COMBO_BOX (cover_preferences->priv->amazon_country), i);
-                        break;
-                }
-                gtk_combo_box_set_active (GTK_COMBO_BOX (cover_preferences->priv->amazon_country), 0);
-        }
-        g_free (current_country);
+        /* Select activate amazon country */
+        gtk_tree_model_foreach (gtk_combo_box_get_model (GTK_COMBO_BOX (cover_preferences->priv->amazon_country)),
+                                (GtkTreeModelForeachFunc) ario_cover_preferences_sync_cover_foreach,
+                                cover_preferences);
 
+        /* Synchonize covers providers */
         ario_cover_preferences_sync_cover_providers (cover_preferences);
 }
 
@@ -260,7 +237,8 @@ void
 ario_cover_preferences_covertree_check_changed_cb (GtkCheckButton *butt,
                                                    ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
+        /* Update configuration */
         ario_conf_set_boolean (PREF_COVER_TREE_HIDDEN,
                                !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cover_preferences->priv->covertree_check)));
 }
@@ -269,49 +247,71 @@ void
 ario_cover_preferences_automatic_check_changed_cb (GtkCheckButton *butt,
                                                    ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
+        /* Update configuration */
         ario_conf_set_boolean (PREF_AUTOMATIC_GET_COVER,
                                gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cover_preferences->priv->automatic_check)));
 }
 
 void
-ario_cover_preferences_amazon_country_changed_cb (GtkComboBoxEntry *combobox,
+ario_cover_preferences_amazon_country_changed_cb (GtkComboBox *combobox,
                                                   ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
-        int i;
+        ARIO_LOG_FUNCTION_START;
+        GtkTreeModel *treemodel;
+        GtkTreeIter iter;
+        gchar *country;
 
-        i = gtk_combo_box_get_active (GTK_COMBO_BOX (cover_preferences->priv->amazon_country));
+        /* Get country of activated row */
+        treemodel = gtk_combo_box_get_model (combobox);
+        gtk_combo_box_get_active_iter (combobox,
+                                       &iter);
+        gtk_tree_model_get (treemodel, &iter,
+                            0, &country,
+                            -1);
 
-        ario_conf_set_string (PREF_COVER_AMAZON_COUNTRY, 
-                              amazon_countries[i]);
+        /* Update configuration */
+        ario_conf_set_string (PREF_COVER_AMAZON_COUNTRY,
+                              country);
+        g_free (country);
 }
 
 void
 ario_cover_preferences_top_button_cb (GtkWidget *widget,
                                       ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GtkTreeIter iter;
         GtkTreeModel *model;
         gchar *id;
         ArioCoverProvider *cover_provider;
         GSList *providers;
 
+        /* Stop here if no row is selected */
         if (!gtk_tree_selection_get_selected (cover_preferences->priv->covers_selection,
                                               &model,
                                               &iter))
                 return;
+
+        /* Get ID of selected provider */
         gtk_tree_model_get (model, &iter, ID_COLUMN, &id, -1);
+
+        /* Get selected covers provider */
         cover_provider = ario_cover_manager_get_provider_from_id (ario_cover_manager_get_instance (), id);
         g_free (id);
+
+        /* Get list of covers providers */
         providers = ario_cover_manager_get_providers (ario_cover_manager_get_instance ());
 
+        /* Remove provider from list */
         providers = g_slist_remove (providers, cover_provider);
+
+        /* Add provider to head of list */
         providers = g_slist_prepend (providers, cover_provider);
 
         ario_cover_manager_set_providers (ario_cover_manager_get_instance (), providers);
 
+        /* Synchronize tree */
         ario_cover_preferences_sync_cover_providers (cover_preferences);
 }
 
@@ -319,7 +319,7 @@ void
 ario_cover_preferences_up_button_cb (GtkWidget *widget,
                                      ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GtkTreeIter iter;
         GtkTreeModel *model;
         gchar *id;
@@ -327,21 +327,33 @@ ario_cover_preferences_up_button_cb (GtkWidget *widget,
         GSList *providers;
         gint index;
 
+        /* Stop here if no row is selected */
         if (!gtk_tree_selection_get_selected (cover_preferences->priv->covers_selection,
                                               &model,
                                               &iter))
                 return;
+
+        /* Get ID of selected provider */
         gtk_tree_model_get (model, &iter, ID_COLUMN, &id, -1);
+
+        /* Get selected covers provider */
         cover_provider = ario_cover_manager_get_provider_from_id (ario_cover_manager_get_instance (), id);
         g_free (id);
+
+        /* Get list of covers providers */
         providers = ario_cover_manager_get_providers (ario_cover_manager_get_instance ());
 
+        /* Get index of selected provider */
         index = g_slist_index (providers, cover_provider);
         if (index > 0) {
+                /* Remove provider from list */
                 providers = g_slist_remove (providers, cover_provider);
+
+                /* Insert provider at previous position */
                 providers = g_slist_insert (providers, cover_provider, index - 1);
                 ario_cover_manager_set_providers (ario_cover_manager_get_instance (), providers);
 
+                /* Synchronize tree */
                 ario_cover_preferences_sync_cover_providers (cover_preferences);
         }
 }
@@ -350,7 +362,7 @@ void
 ario_cover_preferences_down_button_cb (GtkWidget *widget,
                                        ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GtkTreeIter iter;
         GtkTreeModel *model;
         gchar *id;
@@ -358,20 +370,33 @@ ario_cover_preferences_down_button_cb (GtkWidget *widget,
         GSList *providers;
         gint index;
 
+        /* Stop here if no row is selected */
         if (!gtk_tree_selection_get_selected (cover_preferences->priv->covers_selection,
                                               &model,
                                               &iter))
                 return;
+
+        /* Get ID of selected provider */
         gtk_tree_model_get (model, &iter, ID_COLUMN, &id, -1);
+
+        /* Get selected covers provider */
         cover_provider = ario_cover_manager_get_provider_from_id (ario_cover_manager_get_instance (), id);
         g_free (id);
+
+        /* Get list of covers providers */
         providers = ario_cover_manager_get_providers (ario_cover_manager_get_instance ());
 
+        /* Get index of selected provider */
         index = g_slist_index (providers, cover_provider);
+
+        /* Remove provider from list */
         providers = g_slist_remove (providers, cover_provider);
+
+        /* Insert provider at next position */
         providers = g_slist_insert (providers, cover_provider, index + 1);
         ario_cover_manager_set_providers (ario_cover_manager_get_instance (), providers);
 
+        /* Synchronize tree */
         ario_cover_preferences_sync_cover_providers (cover_preferences);
 }
 
@@ -379,36 +404,47 @@ void
 ario_cover_preferences_bottom_button_cb (GtkWidget *widget,
                                          ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GtkTreeIter iter;
         GtkTreeModel *model;
         gchar *id;
         ArioCoverProvider *cover_provider;
         GSList *providers;
 
+        /* Stop here if no row is selected */
         if (!gtk_tree_selection_get_selected (cover_preferences->priv->covers_selection,
                                               &model,
                                               &iter))
                 return;
+
+        /* Get ID of selected provider */
         gtk_tree_model_get (model, &iter, ID_COLUMN, &id, -1);
+
+        /* Get selected covers provider */
         cover_provider = ario_cover_manager_get_provider_from_id (ario_cover_manager_get_instance (), id);
         g_free (id);
+
+        /* Get list of covers providers */
         providers = ario_cover_manager_get_providers (ario_cover_manager_get_instance ());
 
+        /* Remove provider from list */
         providers = g_slist_remove (providers, cover_provider);
+
+        /* Add provider to end of list */
         providers = g_slist_append (providers, cover_provider);
 
         ario_cover_manager_set_providers (ario_cover_manager_get_instance (), providers);
 
+        /* Synchronize tree */
         ario_cover_preferences_sync_cover_providers (cover_preferences);
 }
 
-static void
+void
 ario_cover_preferences_cover_toggled_cb (GtkCellRendererToggle *cell,
                                          gchar *path_str,
                                          ArioCoverPreferences *cover_preferences)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         gboolean state;
         gchar *id;
         GtkTreeIter iter;
@@ -417,11 +453,18 @@ ario_cover_preferences_cover_toggled_cb (GtkCellRendererToggle *cell,
         ArioCoverProvider *cover_provider;
 
         if (gtk_tree_model_get_iter (model, &iter, path)) {
+                /* Get info from toggled row */
                 gtk_tree_model_get (model, &iter, ENABLED_COLUMN, &state, ID_COLUMN, &id, -1);
                 state = !state;
+
+                /* Get covers provider corresponding to toggled row */
                 cover_provider = ario_cover_manager_get_provider_from_id (ario_cover_manager_get_instance (), id);
+
+                /* (De)activate cover provider */
                 ario_cover_provider_set_active (cover_provider, state);
                 g_free (id);
+
+                /* Update tree */
                 gtk_list_store_set (GTK_LIST_STORE (model), &iter, ENABLED_COLUMN, state, -1);
         }
         gtk_tree_path_free (path);
