@@ -56,7 +56,7 @@ static gboolean ario_mpd_check_errors (void);
 static gboolean ario_mpd_is_connected (void);
 static GSList * ario_mpd_list_tags (const ArioServerTag tag,
                                     const ArioServerCriteria *criteria);
-static gboolean ario_mpd_album_is_present (const GSList *albums,
+static gboolean ario_mpd_album_is_present (GHashTable *albums,
                                            const char *album);
 static GSList * ario_mpd_get_albums (const ArioServerCriteria *criteria);
 static GSList * ario_mpd_get_songs (const ArioServerCriteria *criteria,
@@ -576,28 +576,21 @@ ario_mpd_list_tags (const ArioServerTag tag,
 }
 
 static gboolean
-ario_mpd_album_is_present (const GSList *albums,
+ario_mpd_album_is_present (GHashTable *albums,
                            const char *album)
 {
         ARIO_LOG_FUNCTION_START;
-        const GSList *tmp;
-        ArioServerAlbum *mpd_album;
-
-        for (tmp = albums; tmp; tmp = g_slist_next (tmp)) {
-                mpd_album = tmp->data;
-                if (!g_utf8_collate (album, mpd_album->album)) {
-                        return TRUE;
-                }
-        }
-        return FALSE;
+        return g_hash_table_lookup (albums, album) != NULL;
 }
 
 static GSList *
 ario_mpd_get_albums (const ArioServerCriteria *criteria)
 {
         ARIO_LOG_FUNCTION_START;
-        GSList *albums = NULL;
+        GHashTable *albums;
         const GSList *tmp;
+        GList *values;
+        GSList *result = NULL;
         mpd_InfoEntity *entity = NULL;
         ArioServerAlbum *mpd_album;
         ArioServerAtomicCriteria *atomic_criteria;
@@ -606,6 +599,8 @@ ario_mpd_get_albums (const ArioServerCriteria *criteria)
         if (!instance->priv->connection)
                 return NULL;
 
+        albums = g_hash_table_new (g_str_hash, g_str_equal);
+
         if (!criteria) {
                 mpd_sendListallInfoCommand (instance->priv->connection, "/");
         } else {
@@ -672,7 +667,7 @@ ario_mpd_get_albums (const ArioServerCriteria *criteria)
                         mpd_album->date = NULL;
                 }
 
-                albums = g_slist_append (albums, mpd_album);
+                g_hash_table_insert(albums, mpd_album->album, (gpointer) mpd_album);
 
                 mpd_freeInfoEntity (entity);
         }
@@ -681,7 +676,16 @@ ario_mpd_get_albums (const ArioServerCriteria *criteria)
         if (instance->priv->support_idle && instance->priv->connection)
                 mpd_startIdle (instance->priv->connection, ario_mpd_idle_cb, NULL);
 
-        return albums;
+        for (values = g_hash_table_get_values (albums); values; values = g_list_next (values))
+                result = g_slist_append (result, values->data);
+
+        /*
+         * we don't need to free neither the keys nor the values since
+         * they are returned within the resulting list
+         */
+        g_hash_table_destroy (albums);
+
+        return result;
 }
 
 static GSList *
