@@ -20,13 +20,13 @@
 #include "shell/ario-shell-coverdownloader.h"
 #include <gtk/gtk.h>
 #include <string.h>
-
 #include <glib/gi18n.h>
-#include "covers/ario-cover.h"
-#include "covers/ario-cover-manager.h"
-#include "covers/ario-cover-handler.h"
-#include "lib/rb-glade-helpers.h"
+
 #include "ario-debug.h"
+#include "covers/ario-cover.h"
+#include "covers/ario-cover-handler.h"
+#include "covers/ario-cover-manager.h"
+#include "lib/gtk-builder-helpers.h"
 #include "servers/ario-server.h"
 
 static void ario_shell_coverdownloader_finalize (GObject *object);
@@ -78,19 +78,21 @@ G_DEFINE_TYPE (ArioShellCoverdownloader, ario_shell_coverdownloader, GTK_TYPE_WI
 static void
 ario_shell_coverdownloader_class_init (ArioShellCoverdownloaderClass *klass)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+        /* Virtual methods */
         object_class->finalize = ario_shell_coverdownloader_finalize;
         object_class->constructor = ario_shell_coverdownloader_constructor;
 
+        /* Private attributes */
         g_type_class_add_private (klass, sizeof (ArioShellCoverdownloaderPrivate));
 }
 
 static void
 ario_shell_coverdownloader_init (ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         ario_shell_coverdownloader->priv = ARIO_SHELL_COVERDOWNLOADER_GET_PRIVATE (ario_shell_coverdownloader);
         ario_shell_coverdownloader->priv->cancelled = FALSE;
 }
@@ -98,7 +100,7 @@ ario_shell_coverdownloader_init (ArioShellCoverdownloader *ario_shell_coverdownl
 static void
 ario_shell_coverdownloader_finalize (GObject *object)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         ArioShellCoverdownloader *ario_shell_coverdownloader;
 
         g_return_if_fail (object != NULL);
@@ -108,6 +110,7 @@ ario_shell_coverdownloader_finalize (GObject *object)
 
         g_return_if_fail (ario_shell_coverdownloader->priv != NULL);
 
+        /* Wait for thread to finish */
         if (ario_shell_coverdownloader->priv->thread)
                 g_thread_join (ario_shell_coverdownloader->priv->thread);
 
@@ -123,9 +126,10 @@ ario_shell_coverdownloader_finalize (GObject *object)
 GtkWidget *
 ario_shell_coverdownloader_new (void)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         ArioShellCoverdownloader *ario_shell_coverdownloader;
 
+        /* Ensure that only one coverdownloader is instantiated at the same time */
         if (is_instantiated)
                 return NULL;
         else
@@ -143,47 +147,50 @@ static GObject *
 ario_shell_coverdownloader_constructor (GType type, guint n_construct_properties,
                                         GObjectConstructParam *construct_properties)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         ArioShellCoverdownloader *ario_shell_coverdownloader;
         ArioShellCoverdownloaderClass *klass;
         GObjectClass *parent_class;
-        GladeXML *xml = NULL;
+        GtkBuilder *builder;
         GtkWidget *vbox;
 
+        /* Call parent constructor */
         klass = ARIO_SHELL_COVERDOWNLOADER_CLASS (g_type_class_peek (TYPE_ARIO_SHELL_COVERDOWNLOADER));
-
         parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
         ario_shell_coverdownloader = ARIO_SHELL_COVERDOWNLOADER (parent_class->constructor (type, n_construct_properties,
                                                                                             construct_properties));
 
-        xml = rb_glade_xml_new (GLADE_PATH "cover-progress.glade", "vbox", NULL);
-        vbox =
-                glade_xml_get_widget (xml, "vbox");
+        /* Create UI using GtkBuilder */
+        builder = gtk_builder_helpers_new (UI_PATH "cover-progress.ui",
+                                           NULL);
+
+        /* Get pointers to various widgets */
+        vbox = GTK_WIDGET (gtk_builder_get_object (builder, "vbox"));
         ario_shell_coverdownloader->priv->progress_artist_label =
-                glade_xml_get_widget (xml, "artist_label");
+                GTK_WIDGET (gtk_builder_get_object (builder, "artist_label"));
         ario_shell_coverdownloader->priv->progress_album_label =
-                glade_xml_get_widget (xml, "album_label");
+                GTK_WIDGET (gtk_builder_get_object (builder, "album_label"));
         ario_shell_coverdownloader->priv->progressbar =
-                glade_xml_get_widget (xml, "progressbar");
+                GTK_WIDGET (gtk_builder_get_object (builder, "progressbar"));
         ario_shell_coverdownloader->priv->progress_hbox =
-                glade_xml_get_widget (xml, "hbox2");
+                GTK_WIDGET (gtk_builder_get_object (builder, "hbox2"));
         ario_shell_coverdownloader->priv->progress_const_artist_label =
-                glade_xml_get_widget (xml, "const_artist_label");
+                GTK_WIDGET (gtk_builder_get_object (builder, "const_artist_label"));
         ario_shell_coverdownloader->priv->cancel_button =
-                glade_xml_get_widget (xml, "cancel_button");
+                GTK_WIDGET (gtk_builder_get_object (builder, "cancel_button"));
         ario_shell_coverdownloader->priv->close_button =
-                glade_xml_get_widget (xml, "close_button");
+                GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
 
-        rb_glade_boldify_label (xml, "operation_label");
-
-        g_object_unref (G_OBJECT (xml));
+        gtk_builder_helpers_boldify_label (builder, "operation_label");
 
+        /* Set window properties */
         gtk_window_set_title (GTK_WINDOW (ario_shell_coverdownloader), _("Music Player Cover Download"));
-        gtk_container_add (GTK_CONTAINER (ario_shell_coverdownloader), 
+        gtk_container_add (GTK_CONTAINER (ario_shell_coverdownloader),
                            vbox);
         gtk_window_set_position (GTK_WINDOW (ario_shell_coverdownloader),
                                  GTK_WIN_POS_CENTER);
 
+        /* Connect signals for user actions */
         g_signal_connect (ario_shell_coverdownloader->priv->cancel_button,
                           "clicked",
                           G_CALLBACK (ario_shell_coverdownloader_cancel_cb),
@@ -199,6 +206,8 @@ ario_shell_coverdownloader_constructor (GType type, guint n_construct_properties
                           G_CALLBACK (ario_shell_coverdownloader_window_delete_cb),
                           ario_shell_coverdownloader);
 
+        g_object_unref (builder);
+
         return G_OBJECT (ario_shell_coverdownloader);
 }
 
@@ -206,7 +215,7 @@ static void
 ario_shell_coverdownloader_close_cb (GtkButton *button,
                                      ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         /* Close button pressed : we close and destroy the window */
         ario_shell_coverdownloader->priv->cancelled = TRUE;
         gtk_widget_hide (GTK_WIDGET (ario_shell_coverdownloader));
@@ -217,7 +226,7 @@ static void
 ario_shell_coverdownloader_cancel_cb (GtkButton *button,
                                       ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         /* Cancel button pressed : we wait until the end of the current download and we stop the search */
         ario_shell_coverdownloader->priv->cancelled = TRUE;
 }
@@ -227,12 +236,12 @@ ario_shell_coverdownloader_window_delete_cb (GtkWidget *window,
                                              GdkEventAny *event,
                                              ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         if (!ario_shell_coverdownloader->priv->cancelled) {
-                /* window destroyed for the first time : we wait until the end of the current download and we stop the search */
+                /* Window destroyed for the first time : we wait until the end of the current download and we stop the search */
                 ario_shell_coverdownloader->priv->cancelled = TRUE;
         } else {
-                /* window destroyed for the second time : we close and destroy the window */
+                /* Window destroyed for the second time : we close and destroy the window */
                 gtk_widget_hide (GTK_WIDGET (ario_shell_coverdownloader));
                 gtk_widget_destroy (GTK_WIDGET (ario_shell_coverdownloader));
         }
@@ -243,19 +252,19 @@ ario_shell_coverdownloader_window_delete_cb (GtkWidget *window,
 static gboolean
 ario_shell_coverdownloader_refresh (gpointer data)
 {
+        /* Wait for UI refresh */
         while (gtk_events_pending ())
                 gtk_main_iteration ();
 
         return FALSE;
 }
 
-static gboolean 
+static gboolean
 ario_shell_coverdownloader_progress_start (ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         gtk_window_resize (GTK_WINDOW (ario_shell_coverdownloader), 350, 150);
 
-        /*gtk_window_set_policy (GTK_WINDOW (ario_shell_coverdownloader), FALSE, TRUE, FALSE);*/
         gtk_window_set_resizable (GTK_WINDOW (ario_shell_coverdownloader),
                                   FALSE);
 
@@ -281,14 +290,14 @@ typedef struct
 static gboolean
 ario_shell_coverdownloader_progress_update (ArioShellCoverdownloaderIdleData *data)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         /* We have already searched for nb_covers_done covers */
-        gdouble nb_covers_done = (data->ario_shell_coverdownloader->priv->nb_covers_found 
-                                  + data->ario_shell_coverdownloader->priv->nb_covers_not_found 
+        gdouble nb_covers_done = (data->ario_shell_coverdownloader->priv->nb_covers_found
+                                  + data->ario_shell_coverdownloader->priv->nb_covers_not_found
                                   + data->ario_shell_coverdownloader->priv->nb_covers_already_exist);
 
         /* We update the progress bar */
-        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (data->ario_shell_coverdownloader->priv->progressbar), 
+        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (data->ario_shell_coverdownloader->priv->progressbar),
                                        nb_covers_done / data->ario_shell_coverdownloader->priv->nb_covers);
 
         /* We update the artist and the album label */
@@ -308,7 +317,7 @@ ario_shell_coverdownloader_progress_update (ArioShellCoverdownloaderIdleData *da
 static gboolean
 ario_shell_coverdownloader_progress_end (ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         char *label_text;
 
         /* We only want the close button at the end, not the cancel button */
@@ -323,8 +332,8 @@ ario_shell_coverdownloader_progress_end (ArioShellCoverdownloader *ario_shell_co
                             _("Download Finished!"));
 
         /* We show the numbers of covers found and not found */
-        label_text = g_strdup_printf (_("%i covers found\n%i covers not found\n%i covers already exist"), 
-                                      ario_shell_coverdownloader->priv->nb_covers_found, 
+        label_text = g_strdup_printf (_("%i covers found\n%i covers not found\n%i covers already exist"),
+                                      ario_shell_coverdownloader->priv->nb_covers_found,
                                       ario_shell_coverdownloader->priv->nb_covers_not_found,
                                       ario_shell_coverdownloader->priv->nb_covers_already_exist);
 
@@ -342,9 +351,13 @@ void
 ario_shell_coverdownloader_get_covers (ArioShellCoverdownloader *ario_shell_coverdownloader,
                                        const ArioShellCoverdownloaderOperation operation)
 {
-        ARIO_LOG_FUNCTION_START
-        GSList *albums = ario_server_get_albums (NULL);
+        ARIO_LOG_FUNCTION_START;
+        GSList *albums;
 
+        /* Get list of all albums of server */
+        albums = ario_server_get_albums (NULL);
+
+        /* Get covers of albums */
         ario_shell_coverdownloader_get_covers_from_albums (ario_shell_coverdownloader,
                                                            albums,
                                                            operation);
@@ -356,7 +369,7 @@ ario_shell_coverdownloader_get_covers (ArioShellCoverdownloader *ario_shell_cove
 static gboolean
 ario_shell_coverdownloader_force_reload (gpointer data)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         ario_cover_handler_force_reload();
 
         return FALSE;
@@ -365,7 +378,7 @@ ario_shell_coverdownloader_force_reload (gpointer data)
 static gpointer
 ario_shell_coverdownloader_get_covers_from_albums_thread (ArioShellCoverdownloader *ario_shell_coverdownloader)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GSList *tmp;
 
         if (!ario_shell_coverdownloader->priv->albums)
@@ -404,12 +417,13 @@ ario_shell_coverdownloader_get_covers_from_albums (ArioShellCoverdownloader *ari
                                                    const GSList *albums,
                                                    const ArioShellCoverdownloaderOperation operation)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         const GSList *tmp;
 
         if (!albums)
                 return;
 
+        /* Copy the list of albums */
         ario_shell_coverdownloader->priv->albums = NULL;
         for (tmp = albums; tmp; tmp = g_slist_next (tmp)) {
                 ario_shell_coverdownloader->priv->albums = g_slist_append (ario_shell_coverdownloader->priv->albums, ario_server_copy_album (tmp->data));
@@ -417,6 +431,7 @@ ario_shell_coverdownloader_get_covers_from_albums (ArioShellCoverdownloader *ari
 
         ario_shell_coverdownloader->priv->operation = operation;
 
+        /* Launch thread for cover download */
         ario_shell_coverdownloader->priv->thread = g_thread_create ((GThreadFunc) ario_shell_coverdownloader_get_covers_from_albums_thread,
                                                                     ario_shell_coverdownloader,
                                                                     TRUE,
@@ -428,7 +443,7 @@ ario_shell_coverdownloader_get_cover_from_album (ArioShellCoverdownloader *ario_
                                                  const ArioServerAlbum *server_album,
                                                  const ArioShellCoverdownloaderOperation operation)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         const gchar *artist;
         const gchar *album;
         const gchar *path;
@@ -478,7 +493,7 @@ ario_shell_coverdownloader_get_cover (ArioShellCoverdownloader *ario_shell_cover
                                       const char *album,
                                       const char *path)
 {
-        ARIO_LOG_FUNCTION_START
+        ARIO_LOG_FUNCTION_START;
         GArray *size;
         GSList *data = NULL;
         gboolean ret;
