@@ -81,7 +81,7 @@ static void ario_tree_append_drag_data (ArioTree *tree,
                                         GtkTreeIter *iter,
                                         ArioTreeStringData *data);
 static void ario_tree_add_to_playlist (ArioTree *tree,
-                                       const gboolean play);
+                                       const PlaylistAction action);
 static void ario_tree_add_data_free (ArioTreeAddData *data);
 
 struct ArioTreePrivate
@@ -101,7 +101,8 @@ typedef struct
 enum
 {
         PROP_0,
-        PROP_UI_MANAGER
+        PROP_UI_MANAGER,
+        PROP_TAG
 };
 
 /* Object signals */
@@ -158,6 +159,15 @@ ario_tree_class_init (ArioTreeClass *klass)
                                                               GTK_TYPE_UI_MANAGER,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
+        g_object_class_install_property (object_class,
+                                         PROP_TAG,
+                                         g_param_spec_uint ("tag",
+                                                            "Tag",
+                                                            "Tag ID",
+                                                            0, G_MAXUINT,
+                                                            0,
+                                                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+
         /* Object signals */
         ario_tree_signals[SELECTION_CHANGED] =
                 g_signal_new ("selection_changed",
@@ -226,6 +236,9 @@ ario_tree_set_property (GObject *object,
         case PROP_UI_MANAGER:
                 tree->priv->ui_manager = g_value_get_object (value);
                 break;
+        case PROP_TAG:
+                tree->tag = g_value_get_uint (value);
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
                 break;
@@ -245,6 +258,9 @@ ario_tree_get_property (GObject *object,
         case PROP_UI_MANAGER:
                 g_value_set_object (value, tree->priv->ui_manager);
                 break;
+        case PROP_TAG:
+                g_value_set_uint (value, tree->tag);
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
                 break;
@@ -358,9 +374,9 @@ ario_tree_new (GtkUIManager *mgr,
         GType type;
 
         /* Tree factory: Create a tree of the appropriate type */
-        if (tag == MPD_TAG_ITEM_ALBUM && !is_first) {
+        if (tag == ARIO_TAG_ALBUM && !is_first) {
                 type = TYPE_ARIO_TREE_ALBUMS;
-        } else if (tag == MPD_TAG_ITEM_TITLE && !is_first) {
+        } else if (tag == ARIO_TAG_TITLE && !is_first) {
                 type = TYPE_ARIO_TREE_SONGS;
         } else {
                 type = TYPE_ARIO_TREE;
@@ -368,10 +384,10 @@ ario_tree_new (GtkUIManager *mgr,
 
         tree = ARIO_TREE (g_object_new (type,
                                         "ui-manager", mgr,
+                                        "tag", tag,
                                         NULL));
 
         g_return_val_if_fail (tree->priv != NULL, NULL);
-        tree->tag = tag;
         tree->is_first = is_first;
 
         return GTK_WIDGET (tree);
@@ -385,10 +401,10 @@ ario_tree_popup_menu_cb (ArioDndTree* dnd_tree,
         GtkWidget *menu;
 
         /* Get the most appropriate menu */
-        if ((tree->tag == MPD_TAG_ITEM_ALBUM)
+        if ((tree->tag == ARIO_TAG_ALBUM)
             && (gtk_tree_selection_count_selected_rows (tree->selection) == 1)) {
                 menu = gtk_ui_manager_get_widget (tree->priv->ui_manager, "/BrowserAlbumsPopupSingle");
-        } else if (tree->tag == MPD_TAG_ITEM_TITLE) {
+        } else if (tree->tag == ARIO_TAG_TITLE) {
                 menu = gtk_ui_manager_get_widget (tree->priv->ui_manager, "/BrowserSongsPopup");
         } else {
                 menu = gtk_ui_manager_get_widget (tree->priv->ui_manager, "/BrowserPopup");
@@ -408,7 +424,9 @@ ario_tree_activate_cb (ArioDndTree* dnd_tree,
 {
         ARIO_LOG_FUNCTION_START;
         /* Add songs to main playlist */
-        ario_tree_cmd_add (tree, FALSE);
+        ario_tree_cmd_add (tree, 
+                           ario_conf_get_integer (PREF_DOUBLECLICK_BEHAVIOR,
+                                                  PREF_DOUBLECLICK_BEHAVIOR_DEFAULT));
 }
 
 static void
@@ -497,7 +515,7 @@ ario_tree_drag_data_get_cb (GtkWidget *widget,
                                              &data);
 
         /* Set drag data */
-        gtk_selection_data_set (selection_data, selection_data->target, 8, (const guchar *) string->str,
+        gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data), 8, (const guchar *) string->str,
                                 strlen (string->str) * sizeof(guchar));
 
         g_string_free (string, TRUE);
@@ -795,7 +813,7 @@ ario_tree_get_criterias (ArioTree *tree)
 
 static void
 ario_tree_add_to_playlist (ArioTree *tree,
-                           const gboolean play)
+                           const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         GSList *criterias = NULL;
@@ -803,7 +821,7 @@ ario_tree_add_to_playlist (ArioTree *tree,
         criterias = ario_tree_get_criterias (tree);
 
         /* Append songs corresponfind to current criteria to main playlist */
-        ario_server_playlist_append_criterias (criterias, play, -1);
+        ario_server_playlist_append_criterias (criterias, action, -1);
 
         g_slist_foreach (criterias, (GFunc) ario_server_criteria_free, NULL);
         g_slist_free (criterias);
@@ -811,11 +829,11 @@ ario_tree_add_to_playlist (ArioTree *tree,
 
 void
 ario_tree_cmd_add (ArioTree *tree,
-                   const gboolean play)
+                   const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         /* Call virtual method for songs addition in main playlist */
-        ARIO_TREE_GET_CLASS (tree)->add_to_playlist (tree, play);
+        ARIO_TREE_GET_CLASS (tree)->add_to_playlist (tree, action);
 }
 
 void
