@@ -177,6 +177,7 @@ ario_header_constructor (GType type, guint n_construct_properties,
         GtkTargetEntry *target_entry;
         gint n_elem;
         GtkWidget *image, *hbox, *right_hbox, *vbox, *alignment;
+        GList *focus = NULL;
 
         klass = ARIO_HEADER_CLASS (g_type_class_peek (TYPE_ARIO_HEADER));
 
@@ -206,11 +207,8 @@ ario_header_constructor (GType type, guint n_construct_properties,
                                                               GTK_ICON_SIZE_LARGE_TOOLBAR);
         g_object_ref (header->priv->pause_image);
         gtk_widget_show (header->priv->pause_image);
-
         header->priv->play_pause_button = gtk_button_new ();
-
         gtk_container_add (GTK_CONTAINER (header->priv->play_pause_button), header->priv->pause_image);
-
         g_signal_connect_swapped (header->priv->play_pause_button,
                                   "clicked",
                                   G_CALLBACK (ario_header_playpause),
@@ -393,6 +391,10 @@ ario_header_constructor (GType type, guint n_construct_properties,
         gtk_container_add (GTK_CONTAINER (alignment), right_hbox);
         gtk_box_pack_end (GTK_BOX (header), alignment, FALSE, TRUE, 0);
 
+        /* Set focus chain */
+        focus = g_list_append (focus, header->priv->scale);
+        gtk_container_set_focus_chain (GTK_CONTAINER (header), focus);
+
         return G_OBJECT (header);
 }
 
