@@ -1377,7 +1377,11 @@ ario_playlist_drag_leave_cb (GtkWidget *widget,
 
         /* Call the appropriate functions depending on data type */
         if (gtk_selection_data_get_data_type (data) == gdk_atom_intern ("text/internal-list", TRUE)) {
+#if GTK_CHECK_VERSION(2, 22, 0)
+                if (gdk_drag_context_get_actions (context) & GDK_ACTION_COPY)
+#else
                 if (context->action & GDK_ACTION_COPY)
+#endif
                         ario_playlist_copy_rows (x, y);
                 else
                         ario_playlist_move_rows (x, y);
@@ -1739,7 +1743,7 @@ ario_playlist_cmd_save (GtkAction *action,
                                                  GTK_DIALOG_MODAL,
                                                  GTK_MESSAGE_QUESTION,
                                                  GTK_BUTTONS_YES_NO,
-                                                 _("Playlist already exists. Do you want to ovewrite it?"));
+                                                 _("Playlist already exists. Do you want to overwrite it?"));
 
                 retval = gtk_dialog_run (GTK_DIALOG (dialog));
                 gtk_widget_destroy (dialog);
