@@ -27,11 +27,7 @@
 #include <config.h>
 #include "shell/ario-shell.h"
 #include <gtk/gtkuimanager.h>
-#ifdef ENABLE_EGGTRAYICON
-#include "lib/eggtrayicon.h"
-#else
 #include <gtk/gtkstatusicon.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -54,21 +50,14 @@ typedef struct ArioTrayIconPrivate ArioTrayIconPrivate;
  */
 typedef struct
 {
-#ifdef ENABLE_EGGTRAYICON
-        EggTrayIcon parent;
-#else
         GtkStatusIcon parent;
-#endif
+
         ArioTrayIconPrivate *priv;
 } ArioTrayIcon;
 
 typedef struct
 {
-#ifdef ENABLE_EGGTRAYICON
-        EggTrayIconClass parent_class;
-#else
         GtkStatusIconClass parent_class;
-#endif
 } ArioTrayIconClass;
 
 GType                   ario_tray_icon_get_type         (void) G_GNUC_CONST;
@@ -77,8 +66,6 @@ ArioTrayIcon *          ario_tray_icon_new              (GtkActionGroup *group,
                                                          GtkUIManager *mgr,
                                                          ArioShell *shell);
 
-void                    ario_tray_icon_notify           (void);
-
 ArioTrayIcon *          ario_tray_icon_get_instance     (void);
 
 G_END_DECLS
